#
#                Fecundity data compilation and Exploration
#
# --------------------------------------------------------------------------- #
# R script to import fecundity data (number of eggs per polyp and egg volume), 
# conduct preliminary exploration of traits, and then pool them together in 
# relation to colony ID.
# Note: R scripts in this repository should be run from 1 to 6 to avoid errors
# 
# Written by Liam Lachs, School of Natural and Environmental Sciences, Newcastle
# University, UK, on 01/08/2022
# --------------------------------------------------------------------------- #

library(ggplot2)
library(dplyr)
# Collating the number and area of eggs
fec = read.csv("data raw/Egg Sizes.csv")
colnames(fec)
fec = fec[,-c(1,8,9)]


# Average by across years only affects colony 69
fec.av = fec %>%
  group_by(Colony_ID) %>%
  summarise(Year.EggNum = paste(unique(Year),collapse = "_"),
            Eggs.av = mean(Eggs, na.rm = TRUE))

vol = read.csv("data raw/Egg_Volume_Data.csv")

# Acropora egg size from:
# Figueiredo, J., Thomas, C.J., Deleersnijder, E. et al. Global warming decreases connectivity among coral populations. Nat. Clim. Chang. 12, 83–87 (2022). https://doi.org/10.1038/s41558-021-01248-7
F1F = 
  ggplot() + 
  geom_histogram(data = vol,
                 aes(x=Geom.Mean.D*1000),
                 bins = 20, fill = "grey85",
                 colour = "grey30",size = 0.75) + 
  # geom_vline(xintercept = mean(c(532,604)), colour = "firebrick",
  geom_vline(xintercept = 460, colour = "firebrick",
             linetype="dashed",size=1.5) +
  labs(x = bquote(Egg~geometric~mean~diameter~(mu*m)),
       y = "Counts") + 
  theme_bw() + 
  theme(panel.grid = element_blank())
F1F
save(F1F,file="data processed/Figure 1F - Fecundity.Rdata")


summary(vol$Geom.Mean.D, na.rm=T)

vol.av = vol %>%
  group_by(Colony_ID) %>%
  summarise(Year.EggSiz = paste(unique(Year),collapse = "_"),
            Egg.Area = mean(Area),
            Egg.Vol = mean(Volume.spherical))

fec.av = full_join(fec.av,vol.av)

pd = read.csv("data raw/Polyp Density.csv")
pd.av = pd %>%
  group_by(Colony_ID) %>%
  summarise(Polyp_Density.av = mean(Polyp_Density))

fec.av = full_join(fec.av,pd.av)

write.csv(fec.av,"data processed/Fecundity by colony and year.csv",row.names = F)
